<?php

global $newproject_text;
$newproject_text = array (

'createnewproject'	=>	'Crea un nuovo progetto',
'projecttitle'		=>	'Titolo del progetto',
'themestyle'		=>	'Tema / Stile',
'projectprefs'		=>	'Preferenze del progetto',
'defaultproject'	=>	'Progetto predefinito',
'projectlists'		=>	'Lista dei Progetti',
'addnewproject'		=>	'Aggiungi un nuovo progetto',
'showlogo'			=>	'Mostra titolo logo immagine',
'intromessage'		=>	'Messaggio Introduttivo',
'htmlallowed'		=>	'E\' possibile inserire codice HTML',
'createproject'		=>	'Crea un nuovo progetto',
'noone'				=>	'Nessuno',
'defaultcatowner'	=>	'Gestore predefinito della categoria',
'createthisproject'	=>	'Crea questo progetto',
'nopermission'		=>	'Non hai il permesso di usare questa pagina',

// Added in version 0.9.6
'inlineimages'		=>	'Mostra le immagini allegate inline',

// Added in version 0.9.7
'othersview'		=>	'Permetti a chiunque di visualizzare il progetto',
'allowanonopentask'     =>      'Permetti ad utenti anonimi di aprire dei task',
                          
);
?>
